package cokr.xit.fims.sprt.dao;

import java.util.List;

import org.egovframe.rte.psl.dataaccess.mapper.Mapper;

import cokr.xit.fims.sprt.CvlcptDscsn;
import cokr.xit.fims.sprt.CvlcptDscsnQuery;
import cokr.xit.foundation.component.AbstractMapper;
import cokr.xit.foundation.data.DataObject;

/**업무지원 - 민원 상담 내용 정보 DAO
 *
 * <p>상세 설명:
 *
 * <pre>
 * ============ 변경 이력 ============
 * 2023-09-05	JoJH 최초 작성
 * ================================
 * </pre>
 */
@Mapper("cvlcptDscsnMapper")
public interface CvlcptDscsnMapper extends AbstractMapper {

	/**지정한 조건에 따라 민원 상담 내용 목록을 조회하여 반환한다.<br />
	 * @param req 민원 상담 내용 조회 조건
	 * @return 민원 상담 내용 목록
	 */
	List<DataObject> selectCvlcptDscsnList(CvlcptDscsnQuery req);

	/**지정한 조건에 따라 민원 상담 내용 객체들을 반환한다.
	 * @param req 민원 상담 내용 조회 조건
	 * @return 민원 상담 내용 객체 목록
	 */
	List<DataObject> selectCvlcptDscsns(CvlcptDscsnQuery req);

	/**지정한 조건에 따라 민원 상담 내용 건수를 반환한다.
	 * @param req 민원 상담 내용 조회 조건
	 * @return 민원 상담 내용 객체 목록
	 */
	DataObject selectCvlcptDscsnNocs(CvlcptDscsnQuery req);

	/**지정한 조건에 따라 민원 상담 내용 대장 객체의 마지막 1개를 반환한다.
	 * @param cvlcptDscsnId 민원 상담 ID
	 * @return 민원 상담 내용 대장 객체
	 */
	default DataObject selectCvlcptDscsnInfo(CvlcptDscsnQuery req) {
		if (req.getOrderBy() == null) {
			req.setOrderBy("CD.CVLCPT_DSCSN_ID DESC");
		}

		List<DataObject> cvlcptDscsns = selectCvlcptDscsns(req);

		return !cvlcptDscsns.isEmpty() ? cvlcptDscsns.get(0) : null;
	}

	/**민원 상담 내용 정보를 등록한다.
	 * @param params 파라미터
	 * <ul><li>"cvlcptDscsnCn" - 민원 상담 내용</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int insertCvlcptDscsn(CvlcptDscsn cvlcptDscsn);

	/**민원 상담 내용 정보를 수정한다.
	 * @param params 파라미터
	 * <ul><li>"cvlcptDscsnCn" - 민원 상담 내용</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int updateCvlcptDscsn(CvlcptDscsn cvlcptDscsn);

	/**지정한 민원 상담 내용을 삭제한다.
	 * @param params 파라미터
	 * <ul><li>"cvlcptDscsnCn" - 민원 상담 내용</li>
	 *     <li>"currentUser" - 현재 접속한 사용자</li>
	 * </ul>
	 * @return 저장된 정보수
	 */
	int deleteCvlcptDscsn(CvlcptDscsn cvlcptDscsn);

	/**지정한 단속 ID의 단속 정보를 반환한다.
	 * @param crdnId 단속 ID
	 * @return 단속 정보
	 */
	DataObject selectCrdn(CvlcptDscsnQuery req);

}
