package cokr.xit.fims.sprt.service.bean;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Component;

import cokr.xit.fims.cmmn.CmmnUtil;
import cokr.xit.fims.sprt.CvlcptDscsn;
import cokr.xit.fims.sprt.CvlcptDscsnQuery;
import cokr.xit.fims.sprt.dao.CvlcptDscsnMapper;
import cokr.xit.foundation.component.AbstractBean;
import cokr.xit.foundation.data.DataObject;

/**민원 상담 내용 정보 관리 Bean
 *
 * <p>상세 설명:
 *
 * <pre>
 * ============ 변경 이력 ============
 * 2023-09-05	JoJH 최초 작성
 * ================================
 * </pre>
 */
@Component("cvlcptDscsnBean")
public class CvlcptDscsnBean extends AbstractBean {

	/** 민원 상담 내용 정보 DAO */
	@Resource(name = "cvlcptDscsnMapper")
	private CvlcptDscsnMapper cvlcptDscsnMapper;

	/**지정한 조건에 따라 민원 상담 내용 목록을 조회하여 반환한다.
	 * @param req 민원 상담 내용 조회 조건
	 * @return 민원 상담 내용 목록
	 */
	public List<DataObject> getCvlcptDscsnList(CvlcptDscsnQuery req) {
		// 삭제 여부 확인
		if (req.getDelYn() == null) {
			req.setDelYn("N");
		}
		// 정렬 확인
		if (req.getOrderBy() == null) {
			if (req.getBy() == null) {
				req.setOrderBy("REG_DT");
			} else {
				req.setOrderBy(CmmnUtil.convertCamelCaseToSnakeCase(req.getBy()));
			}
		}

		return cvlcptDscsnMapper.selectCvlcptDscsnList(req);
	}

	/**지정한 조건에 따라 민원 상담 내용 객체들을 반환한다.
	 * @param req 민원 상담 내용 조회 조건
	 * @return 민원 상담 내용 객체 목록
	 */
	public List<DataObject> getCvlcptDscsns(CvlcptDscsnQuery req) {
		// 삭제 여부 확인
		if (req.getDelYn() == null) {
			req.setDelYn("N");
		}
		// 정렬 확인
		if (req.getOrderBy() == null) {
			req.setOrderBy("CD.CVLCPT_DSCSN_ID DESC");
		}

		return cvlcptDscsnMapper.selectCvlcptDscsns(req);
	}

	/**지정한 조건에 따라 민원 상담 내용 건수를 반환한다.
	 * @param req 민원 상담 내용 조회 조건
	 * @return 민원 상담 내용 객체 목록
	 */
	public DataObject getCvlcptDscsnNocs(CvlcptDscsnQuery req) {
		return cvlcptDscsnMapper.selectCvlcptDscsnNocs(req);
	}

	/**지정한 민원 상담 ID의 민원 상담 내용 정보를 반환한다.<br />
	 * @param cvlcptDscsnId 민원 상담 ID
	 * @return 민원 상담 내용 정보
	 */
	public DataObject getCvlcptDscsnInfo(CvlcptDscsnQuery req) {
		return cvlcptDscsnMapper.selectCvlcptDscsnInfo(req);
	}

	/**민원 상담 내용 정보를 등록한다.
	 * @param cvlcptDscsnCn 민원 상담 내용
	 * @return 저장 여부
	 * <ul><li>저장됐으면 true</li>
	 *     <li>그렇지 않으면 false</li>
	 * </ul>
	 */
	public String createCvlcptDscsn(CvlcptDscsn cvlcptDscsn) {
		//
		if (cvlcptDscsn.getCvlcptRcptSeCd().equals("01")) {
			cvlcptDscsn.setVhrno(null);
			cvlcptDscsn.setRtpyrNo(null);
		} else if (cvlcptDscsn.getCvlcptRcptSeCd().equals("02")) {
			cvlcptDscsn.setRtpyrNo(null);
		} else if (cvlcptDscsn.getCvlcptRcptSeCd().equals("03")) {
			cvlcptDscsn.setVhrno(null);
		}

		// 민원상담(TB_CVLCPT_DSCSN) 대장을 등록한다.
		int rtnNocs = cvlcptDscsnMapper.insertCvlcptDscsn(cvlcptDscsn);
		if (rtnNocs != 1) {
			throw new RuntimeException("민원상담내용 대장 등록에 실패하였습니다.");	// 예외를 발생시켜서 DB Rollback
		}

		return "[S] 작업이 정상 처리 되었습니다.";
	}

	/**민원 상담 내용 정보를 수정한다.
	 * @param cvlcptDscsnCn 민원 상담 내용
	 * @return 저장 여부
	 * <ul><li>저장됐으면 true</li>
	 *     <li>그렇지 않으면 false</li>
	 * </ul>
	 */
	public String updateCvlcptDscsn(CvlcptDscsn cvlcptDscsn) {
		// 민원상담(TB_CVLCPT_DSCSN) 대장을 수정한다.
		int rtnNocs = cvlcptDscsnMapper.updateCvlcptDscsn(cvlcptDscsn);
		if (rtnNocs != 1) {
			throw new RuntimeException("민원상담내용 대장 수정에 실패하였습니다.");	// 예외를 발생시켜서 DB Rollback
		}

		return "[S] 작업이 정상 처리 되었습니다.";
	}

	/**민원 상담 내용 정보를 삭제한다.
	 * @param cvlcptDscsnCn 민원 상담 내용
	 * @return 저장 여부
	 * <ul><li>저장됐으면 true</li>
	 *     <li>그렇지 않으면 false</li>
	 * </ul>
	 */
	public String removeCvlcptDscsn(CvlcptDscsn cvlcptDscsn) {
		// 민원상담(TB_CVLCPT_DSCSN) 대장을 삭제한다.
		int rtnNocs = cvlcptDscsnMapper.deleteCvlcptDscsn(cvlcptDscsn);
		if (rtnNocs < 1) {
			throw new RuntimeException("민원상담내용 대장 삭제에 실패하였습니다.");	// 예외를 발생시켜서 DB Rollback
		}

		return "[S] 작업이 정상 처리 되었습니다.";
	}

	/**지정한 단속 ID의 단속 정보를 반환한다.<br />
	 * @param crndId 단속 ID
	 * @return 단속 정보
	 */
	public DataObject getCrdnInfo(CvlcptDscsnQuery req) {
		return cvlcptDscsnMapper.selectCrdn(req);
	}

}
